@@ -335,7 +335,7 @@ line2df.sf <- function(l) {
   L1 <- rlang::quo(L1)
 
   ldf_geom <- sf::st_coordinates(l)
-  dplyr::group_by(dplyr::as_data_frame(ldf_geom), !!L1) %>%
+  dplyr::group_by(dplyr::as_tibble(ldf_geom), !!L1) %>%
     dplyr::summarise(
       fx = dplyr::first(!!X), fy = dplyr::first(!!Y),
       tx = dplyr::last(!!X), ty = dplyr::last(!!Y)
@@ -344,9 +344,13 @@ line2df.sf <- function(l) {
 #' @export
 line2df.Spatial <- function(l) {
   ldf_geom <- raster::geom(l)
-  dplyr::group_by_(dplyr::as_data_frame(ldf_geom), "object") %>%
-    dplyr::summarise_(fx = quote(dplyr::first(x)), fy = quote(dplyr::first(y)),
-	tx = quote(dplyr::last(x)), ty = quote(dplyr::last(y)))
+  dplyr::group_by(dplyr::as_tibble(ldf_geom), object) %>%
+    dplyr::summarise(
+      fx = dplyr::first(x),
+      fy = dplyr::first(y),
+      tx = dplyr::last(x),
+      ty = dplyr::last(y)
+      )
 }
 
 #' Convert a spatial (linestring) object to points
@@ -366,6 +370,7 @@ line2df.Spatial <- function(l) {
 #' lpoints <- line2points(l)
 #' lpoints_sfc <- line2points(sf::st_geometry(l))
 #' identical(lpoints, lpoints_sfc)
+#' line2points(sf::st_linestring(matrix(c(0, 0, 2, 2), ncol = 2, byrow = TRUE)))
 #' lpoints2 <- line2pointsn(l)
 #' plot(sf::st_geometry(lpoints), pch = lpoints$id, cex = lpoints$id, col = "black")
 #' plot(lpoints2$geometry, add = TRUE)
@@ -414,6 +419,11 @@ line2points.sfc <- function(l, ids = rep(1:nrow(l), each = 2)) {
   lsfc <- sf::st_as_sf(l)
   line2points(lsfc)
 }
+#' @export
+line2points.sfg <- function(l, ids = rep(1:nrow(l), each = 2)) {
+  lsfc <- sf::st_sfc(l)
+  line2points(lsfc)
+}
 
 #' @rdname line2points
 #' @export
@@ -458,7 +468,7 @@ line2vertices.sf <- function(l) {
 #'
 #' @section Details:
 #'
-#' See [route_cyclestreet()] and other route functions for details.
+#' See [route_cyclestreets()] and other route functions for details.
 #'
 #' A parallel implementation of this was available until version 0.1.8.
 #'
@@ -472,7 +482,7 @@ line2vertices.sf <- function(l) {
 #' typically the origin and destination ids pasted together. If absent, the row name of the
 #' straight lines will be used.
 #' @param time_delay Number or seconds to wait between each query
-#' @param ... Arguments passed to the routing function, e.g. [route_cyclestreet()]
+#' @param ... Arguments passed to the routing function, e.g. [route_cyclestreets()]
 #' @family routes
 #' @export
 #' @examples
@@ -486,20 +496,15 @@ line2vertices.sf <- function(l) {
 #' plot(rq, col = "green", add = TRUE)
 #' plot(rsc)
 #' plot(l, add = T)
-#' line2route(flowlines_sf[2:3, ], route_osrm)
 #' # Plot for a single line to compare 'fastest' and 'quietest' route
 #' n <- 2
 #' plot(l[n, ])
-#' lines(rf[n, ], col = "red")
+#' lines(r[n, ], col = "red")
 #' lines(rq[n, ], col = "green")
-#' # Example with list output
-#' l <- l[1:3, ]
-#' rf_list <- line2route(l = l, list_output = TRUE)
-#' line2route(l[1, ], route_graphhopper)
 #' }
 line2route <-
   function(l,
-           route_fun = stplanr::route_cyclestreet,
+           route_fun = stplanr::route_cyclestreets,
            n_print = 10,
            list_output = FALSE,
            l_id = NA,
@@ -508,7 +513,7 @@ line2route <-
     return_sf <- is(l, "sf")
   if (return_sf) {
     requireNamespace("sf")
-    l <- as(l, "Spatial")
+    l <- sf::as_Spatial(l)
   }
   FUN <- match.fun(route_fun)
   ldf <- line2df(l)
