@@ -22,9 +22,16 @@
 #' route(flowlines_sf[1:4, ], route_fun = cyclestreets::journey, plan = "quietest")
 #' route(flowlines_sf[1:4, ], route_fun = cyclestreets::journey, plan = "balanced")
 #' # with osrm backend - need to set-up osrm first - see routing vignette
-#' route(pct::wight_lines_30, route_fun = osrm::osrmRoute, point_input = TRUE)
-#' # with cyclestreets backend - need to set-up osrm first - see routing vignette
-#' route(pct::wight_lines_30, route_fun = cyclestreets::journey, point_input = TRUE)
+#' if(require(osrm)) {
+#'   message("You have osrm installed")
+#'   osrm::osrmRoute(c(-1.5, 53.8), c(-1.51, 53.81))
+#'   osrm::osrmRoute(c(-1.5, 53.8), c(-1.51, 53.81), , returnclass = "sf")
+#'   # mapview::mapview(.Last.value) # check it's on the route network
+#'   route(pct::wight_lines_30[1:2, ], route_fun = osrm::osrmRoute, returnclass = "sf")
+#' }
+#' if(require(cyclestreets)) { # with cyclestreets backend
+#'   route(pct::wight_lines_30, route_fun = cyclestreets::journey)
+#' }
 #' }
 route <- function(from = NULL, to = NULL, l = NULL,
                   route_fun = stplanr::route_cyclestreets,
@@ -53,7 +60,7 @@ route.sf <- function(from = NULL, to = NULL, l = NULL,
   list_out <- out <- if (requireNamespace("pbapply", quietly = TRUE)) {
     pbapply::pblapply(1:nrow(l), function(i) route_i(FUN, ldf, i, l, ...))
   } else {
-    lapply(1:nrow(l), route_i, FUN = FUN, ldf = ldf, i = 1, ...)
+    lapply(1:nrow(l), function(i) route_i(FUN, ldf, i, l, ...))
   }
 
   list_elements_sf <- most_common_class_of_list(list_out, "sf")
@@ -78,13 +85,12 @@ route.Spatial <- function(from = NULL, to = NULL, l = NULL,
   }
   FUN <- match.fun(route_fun)
   # generate od coordinates
-  ldf <- dplyr::as_data_frame(od_coords(from, to, l))
+  ldf <- dplyr::as_tibble(od_coords(from, to, l))
   # calculate line data frame
   if(is.null(l)) {
     l <- od2line(ldf)
   }
 
-
   # pre-allocate objects
   rc <- as.list(rep(NA, nrow(ldf)))
   rg <- sf::st_sfc(lapply(1:nrow(ldf), function(x) {
@@ -92,7 +98,7 @@ route.Spatial <- function(from = NULL, to = NULL, l = NULL,
   }))
 
   rc[[1]] <- FUN(from = c(ldf$fx[1], ldf$fy[1]), to = c(ldf$tx[1], ldf$ty[1]), ...)
-  rdf <- dplyr::as_data_frame(matrix(ncol = ncol(rc[[1]]@data), nrow = nrow(ldf)))
+  rdf <- dplyr::as_tibble(matrix(ncol = ncol(rc[[1]]@data), nrow = nrow(ldf)))
   names(rdf) <- names(rc[[1]])
 
   rdf[1, ] <- rc[[1]]@data[1, ]
@@ -122,7 +128,6 @@ route.Spatial <- function(from = NULL, to = NULL, l = NULL,
 
   r
 
-
 }
 
 #' Route on local data using the dodgr package
@@ -215,6 +220,7 @@ route_dodgr <- function(from = NULL,
 }
 
 route_i <- function(FUN, ldf, i, l, ...){
+  # browser()
   error_fun <- function(e) {
     e
   }
